@@ -1001,6 +1001,16 @@ class TestBaremetalSet(TestBaremetal):
                           self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_baremetal_set_no_property(self):
+        arglist = ['node_uuid']
+        verifylist = [
+            ('node', 'node_uuid'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.assertFalse(self.baremetal_mock.node.update.called)
+
     def test_baremetal_set_one_property(self):
         arglist = ['node_uuid', '--property', 'path/to/property=value']
         verifylist = [
@@ -1085,6 +1095,26 @@ class TestBaremetalSet(TestBaremetal):
             [{'path': '/name', 'value': 'xxxxx', 'op': 'add'}]
         )
 
+    def test_baremetal_set_chassis(self):
+        chassis = '4f4135ea-7e58-4e3d-bcc4-b87ca16e980b'
+        arglist = [
+            'node_uuid',
+            '--chassis-uuid', chassis,
+        ]
+        verifylist = [
+            ('node', 'node_uuid'),
+            ('chassis_uuid', chassis)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.update.assert_called_once_with(
+            'node_uuid',
+            [{'path': '/chassis_uuid', 'value': chassis, 'op': 'add'}]
+        )
+
     def test_baremetal_set_driver(self):
         arglist = [
             'node_uuid',
@@ -1464,6 +1494,14 @@ class TestBaremetalUnset(TestBaremetal):
                           self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_baremetal_unset_no_property(self):
+        arglist = ['node_uuid']
+        verifylist = [('node', 'node_uuid')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.assertFalse(self.baremetal_mock.node.update.called)
+
     def test_baremetal_unset_one_property(self):
         arglist = ['node_uuid', '--property', 'path/to/property']
         verifylist = [('node', 'node_uuid'),
@@ -1651,6 +1689,25 @@ class TestBaremetalUnset(TestBaremetal):
             [{'path': '/name', 'op': 'remove'}]
         )
 
+    def test_baremetal_unset_chassis_uuid(self):
+        arglist = [
+            'node_uuid',
+            '--chassis-uuid',
+        ]
+        verifylist = [
+            ('node', 'node_uuid'),
+            ('chassis_uuid', True)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.update.assert_called_once_with(
+            'node_uuid',
+            [{'path': '/chassis_uuid', 'op': 'remove'}]
+        )
+
 
 class TestValidate(TestBaremetal):
     def setUp(self):
@@ -1691,3 +1748,69 @@ class TestValidate(TestBaremetal):
         self.cmd.take_action(parsed_args)
 
         self.baremetal_mock.node.validate.assert_called_once_with('node_uuid')
+
+
+class TestVifList(TestBaremetal):
+    def setUp(self):
+        super(TestVifList, self).setUp()
+
+        self.baremetal_mock.node.vif_list.return_value = [
+            baremetal_fakes.FakeBaremetalResource(
+                None,
+                copy.deepcopy(baremetal_fakes.VIFS),
+                loaded=True,
+            ),
+        ]
+
+        # Get the command object to test
+        self.cmd = baremetal_node.VifListBaremetalNode(self.app, None)
+
+    def test_baremetal_vif_list(self):
+        arglist = ['node_uuid']
+        verifylist = [('node', 'node_uuid')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.vif_list.assert_called_once_with('node_uuid')
+
+
+class TestVifAttach(TestBaremetal):
+    def setUp(self):
+        super(TestVifAttach, self).setUp()
+
+        # Get the command object to test
+        self.cmd = baremetal_node.VifAttachBaremetalNode(self.app, None)
+
+    def test_baremetal_vif_attach(self):
+        arglist = ['node_uuid', 'aaa-aaa']
+        verifylist = [('node', 'node_uuid'),
+                      ('vif_id', 'aaa-aaa')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.vif_attach.assert_called_once_with(
+            'node_uuid', 'aaa-aaa')
+
+
+class TestVifDetach(TestBaremetal):
+    def setUp(self):
+        super(TestVifDetach, self).setUp()
+
+        # Get the command object to test
+        self.cmd = baremetal_node.VifDetachBaremetalNode(self.app, None)
+
+    def test_baremetal_vif_detach(self):
+        arglist = ['node_uuid', 'aaa-aaa']
+        verifylist = [('node', 'node_uuid'),
+                      ('vif_id', 'aaa-aaa')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.vif_detach.assert_called_once_with(
+            'node_uuid', 'aaa-aaa')
